Class: Sinatra::Base
- Inherits:
-
Object
- Object
- Sinatra::Base
- Defined in:
- lib/sinatra/base.rb
Overview
Base class for all Sinatra applications and middleware.
Direct Known Subclasses
Constant Summary collapse
- URI_INSTANCE =
URI::Parser.new
- CALLERS_TO_IGNORE =
:nodoc:
[ # :nodoc: /\/sinatra(\/(base|main|show_exceptions))?\.rb$/, # all sinatra code /lib\/tilt.*\.rb$/, # all tilt code /^\(.*\)$/, # generated code /rubygems\/(custom|core_ext\/kernel)_require\.rb$/, # rubygems require hacks /active_support/, # active_support require hacks /bundler(\/(?:runtime|inline))?\.rb/, # bundler require hacks /<internal:/, # internal in ruby >= 1.9.2 /src\/kernel\/bootstrap\/[A-Z]/ # maglev kernel files ]
Constants included from Helpers
Class Attribute Summary collapse
-
.errors ⇒ Object
readonly
Returns the value of attribute errors.
-
.filters ⇒ Object
readonly
Returns the value of attribute filters.
-
.routes ⇒ Object
readonly
Returns the value of attribute routes.
-
.templates ⇒ Object
readonly
Returns the value of attribute templates.
Instance Attribute Summary collapse
-
#app ⇒ Object
Returns the value of attribute app.
-
#env ⇒ Object
Returns the value of attribute env.
-
#params ⇒ Object
Returns the value of attribute params.
-
#request ⇒ Object
Returns the value of attribute request.
-
#response ⇒ Object
Returns the value of attribute response.
-
#template_cache ⇒ Object
readonly
Returns the value of attribute template_cache.
Class Method Summary collapse
-
.add_filter(type, path = /.*/, **options, &block) ⇒ Object
add a filter.
-
.after(path = /.*/, **options, &block) ⇒ Object
Define an after filter; runs after all requests within the same context as route handlers and may access/modify the request and response.
-
.before(path = /.*/, **options, &block) ⇒ Object
Define a before filter; runs before all requests within the same context as route handlers and may access/modify the request and response.
-
.build(app) ⇒ Object
Creates a Rack::Builder instance with all the middleware set up and the given +app+ as end point.
- .call(env) ⇒ Object
-
.caller_files ⇒ Object
Like Kernel#caller but excluding certain magic entries and without line / method information; the resulting array contains filenames only.
-
.caller_locations ⇒ Object
Like caller_files, but containing Arrays rather than strings with the first element being the file, and the second being the line.
-
.condition(name = "#{caller.first[/`.*'/]} condition", &block) ⇒ Object
Add a route condition.
-
.configure(*envs) {|_self| ... } ⇒ Object
Set configuration options for Sinatra and/or the app.
- .delete(path, opts = {}, &bk) ⇒ Object
- .development? ⇒ Boolean
-
.disable(*opts) ⇒ Object
Same as calling
set :option, falsefor each of the given options. -
.enable(*opts) ⇒ Object
Same as calling
set :option, truefor each of the given options. -
.error(*codes, &block) ⇒ Object
Define a custom error handler.
-
.extensions ⇒ Object
Extension modules registered on this class and all superclasses.
-
.get(path, opts = {}, &block) ⇒ Object
Defining a
GEThandler also automatically defines aHEADhandler. - .head(path, opts = {}, &bk) ⇒ Object
-
.helpers(*extensions, &block) ⇒ Object
Makes the methods defined in the block and in the Modules given in
extensionsavailable to the handlers and templates. -
.inline_templates=(file = nil) ⇒ Object
Load embedded templates from the file; uses the caller's FILE when no file is specified.
-
.layout(name = :layout, &block) ⇒ Object
Define the layout template.
- .link(path, opts = {}, &bk) ⇒ Object
-
.middleware ⇒ Object
Middleware used in this class and all superclasses.
-
.mime_type(type, value = nil) ⇒ Object
Lookup or register a mime type in Rack's mime registry.
-
.mime_types(type) ⇒ Object
provides all mime types matching type, including deprecated types: mime_types :html # => ['text/html'] mime_types :js # => ['application/javascript', 'text/javascript'].
-
.new(*args, &bk) ⇒ Object
Create a new instance of the class fronted by its middleware pipeline.
-
.not_found(&block) ⇒ Object
Sugar for
error(404) { ... }. - .options(path, opts = {}, &bk) ⇒ Object
- .patch(path, opts = {}, &bk) ⇒ Object
- .post(path, opts = {}, &bk) ⇒ Object
- .production? ⇒ Boolean
-
.prototype ⇒ Object
The prototype instance used to process requests.
- .public=(value) ⇒ Object
- .public_dir ⇒ Object
- .public_dir=(value) ⇒ Object
- .put(path, opts = {}, &bk) ⇒ Object
-
.quit! ⇒ Object
(also: stop!)
Stop the self-hosted server if running.
-
.register(*extensions, &block) ⇒ Object
Register an extension.
-
.reset! ⇒ Object
Removes all routes, filters, middleware and extension hooks from the current class (not routes/filters/... defined by its superclass).
-
.run!(options = {}, &block) ⇒ Object
(also: start!)
Run the Sinatra app as a self-hosted server using Thin, Puma, Mongrel, or WEBrick (in that order).
-
.running? ⇒ Boolean
Check whether the self-hosted server is running or not.
-
.set(option, value = (not_set = true), ignore_setter = false, &block) ⇒ Object
Sets an option to the given value.
-
.settings ⇒ Object
Access settings defined with Base.set.
-
.template(name, &block) ⇒ Object
Define a named template.
- .test? ⇒ Boolean
- .unlink(path, opts = {}, &bk) ⇒ Object
-
.use(middleware, *args, &block) ⇒ Object
Use the specified Rack middleware.
Instance Method Summary collapse
-
#call(env) ⇒ Object
Rack call interface.
-
#call!(env) ⇒ Object
:nodoc:.
-
#forward ⇒ Object
Forward the request to the downstream app -- middleware only.
-
#halt(*response) ⇒ Object
Exit the current block, halts any further processing of the request, and returns the specified response.
-
#initialize(app = nil) {|_self| ... } ⇒ Base
constructor
A new instance of Base.
-
#new! ⇒ Object
Create a new instance without middleware in front of it.
- #options ⇒ Object
-
#pass(&block) ⇒ Object
Pass control to the next matching route.
-
#settings ⇒ Object
Access settings defined with Base.set.
Methods included from Templates
#asciidoc, #builder, #coffee, #creole, #erb, #erubis, #find_template, #haml, #less, #liquid, #markaby, #markdown, #mediawiki, #nokogiri, #rabl, #radius, #rdoc, #sass, #scss, #slim, #stylus, #textile, #wlang, #yajl
Methods included from Helpers
#attachment, #back, #bad_request?, #body, #cache_control, #client_error?, #content_type, #error, #etag, #expires, #headers, #informational?, #last_modified, #logger, #mime_type, #not_found, #not_found?, #redirect, #redirect?, #send_file, #server_error?, #session, #status, #stream, #success?, #time_for, #uri
Constructor Details
#initialize(app = nil) {|_self| ... } ⇒ Base
Returns a new instance of Base.
899 900 901 902 903 904 |
# File 'lib/sinatra/base.rb', line 899 def initialize(app = nil) super() @app = app @template_cache = Tilt::Cache.new yield self if block_given? end |
Class Attribute Details
.errors ⇒ Object (readonly)
Returns the value of attribute errors.
1182 1183 1184 |
# File 'lib/sinatra/base.rb', line 1182 def errors @errors end |
.filters ⇒ Object (readonly)
Returns the value of attribute filters.
1182 1183 1184 |
# File 'lib/sinatra/base.rb', line 1182 def filters @filters end |
.routes ⇒ Object (readonly)
Returns the value of attribute routes.
1182 1183 1184 |
# File 'lib/sinatra/base.rb', line 1182 def routes @routes end |
.templates ⇒ Object (readonly)
Returns the value of attribute templates.
1182 1183 1184 |
# File 'lib/sinatra/base.rb', line 1182 def templates @templates end |
Instance Attribute Details
#app ⇒ Object
Returns the value of attribute app.
896 897 898 |
# File 'lib/sinatra/base.rb', line 896 def app @app end |
#env ⇒ Object
Returns the value of attribute env.
896 897 898 |
# File 'lib/sinatra/base.rb', line 896 def env @env end |
#params ⇒ Object
Returns the value of attribute params.
896 897 898 |
# File 'lib/sinatra/base.rb', line 896 def params @params end |
#request ⇒ Object
Returns the value of attribute request.
896 897 898 |
# File 'lib/sinatra/base.rb', line 896 def request @request end |
#response ⇒ Object
Returns the value of attribute response.
896 897 898 |
# File 'lib/sinatra/base.rb', line 896 def response @response end |
#template_cache ⇒ Object (readonly)
Returns the value of attribute template_cache.
897 898 899 |
# File 'lib/sinatra/base.rb', line 897 def template_cache @template_cache end |
Class Method Details
.add_filter(type, path = /.*/, **options, &block) ⇒ Object
add a filter
1359 1360 1361 |
# File 'lib/sinatra/base.rb', line 1359 def add_filter(type, path = /.*/, **, &block) filters[type] << compile!(type, path, block, ) end |
.after(path = /.*/, **options, &block) ⇒ Object
Define an after filter; runs after all requests within the same context as route handlers and may access/modify the request and response.
1354 1355 1356 |
# File 'lib/sinatra/base.rb', line 1354 def after(path = /.*/, **, &block) add_filter(:after, path, , &block) end |
.before(path = /.*/, **options, &block) ⇒ Object
Define a before filter; runs before all requests within the same context as route handlers and may access/modify the request and response.
1347 1348 1349 |
# File 'lib/sinatra/base.rb', line 1347 def before(path = /.*/, **, &block) add_filter(:before, path, , &block) end |
.build(app) ⇒ Object
Creates a Rack::Builder instance with all the middleware set up and the given +app+ as end point.
1493 1494 1495 1496 1497 1498 1499 |
# File 'lib/sinatra/base.rb', line 1493 def build(app) builder = Rack::Builder.new setup_default_middleware builder setup_middleware builder builder.run app builder end |
.call(env) ⇒ Object
1501 1502 1503 |
# File 'lib/sinatra/base.rb', line 1501 def call(env) synchronize { prototype.call(env) } end |
.caller_files ⇒ Object
Like Kernel#caller but excluding certain magic entries and without line / method information; the resulting array contains filenames only.
1507 1508 1509 |
# File 'lib/sinatra/base.rb', line 1507 def caller_files cleaned_caller(1).flatten end |
.caller_locations ⇒ Object
Like caller_files, but containing Arrays rather than strings with the first element being the file, and the second being the line.
1513 1514 1515 |
# File 'lib/sinatra/base.rb', line 1513 def caller_locations cleaned_caller 2 end |
.condition(name = "#{caller.first[/`.*'/]} condition", &block) ⇒ Object
Add a route condition. The route is considered non-matching when the block returns false.
1365 1366 1367 |
# File 'lib/sinatra/base.rb', line 1365 def condition(name = "#{caller.first[/`.*'/]} condition", &block) @conditions << generate_method(name, &block) end |
.configure(*envs) {|_self| ... } ⇒ Object
Set configuration options for Sinatra and/or the app. Allows scoping of settings for certain environments.
1425 1426 1427 |
# File 'lib/sinatra/base.rb', line 1425 def configure(*envs) yield self if envs.empty? || envs.include?(environment.to_sym) end |
.delete(path, opts = {}, &bk) ⇒ Object
1394 |
# File 'lib/sinatra/base.rb', line 1394 def delete(path, opts = {}, &bk) route 'DELETE', path, opts, &bk end |
.development? ⇒ Boolean
1419 |
# File 'lib/sinatra/base.rb', line 1419 def development?; environment == :development end |
.disable(*opts) ⇒ Object
Same as calling set :option, false for each of the given options.
1263 1264 1265 |
# File 'lib/sinatra/base.rb', line 1263 def disable(*opts) opts.each { |key| set(key, false) } end |
.enable(*opts) ⇒ Object
Same as calling set :option, true for each of the given options.
1258 1259 1260 |
# File 'lib/sinatra/base.rb', line 1258 def enable(*opts) opts.each { |key| set(key, true) } end |
.error(*codes, &block) ⇒ Object
Define a custom error handler. Optionally takes either an Exception class, or an HTTP status code to specify which errors should be handled.
1270 1271 1272 1273 1274 1275 1276 |
# File 'lib/sinatra/base.rb', line 1270 def error(*codes, &block) args = compile! "ERROR", /.*/, block codes = codes.flat_map(&method(:Array)) codes << Exception if codes.empty? codes << Sinatra::NotFound if codes.include?(404) codes.each { |c| (@errors[c] ||= []) << args } end |
.extensions ⇒ Object
Extension modules registered on this class and all superclasses.
1203 1204 1205 1206 1207 1208 1209 |
# File 'lib/sinatra/base.rb', line 1203 def extensions if superclass.respond_to?(:extensions) (@extensions + superclass.extensions).uniq else @extensions end end |
.get(path, opts = {}, &block) ⇒ Object
Defining a GET handler also automatically defines
a HEAD handler.
1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/sinatra/base.rb', line 1384 def get(path, opts = {}, &block) conditions = @conditions.dup route('GET', path, opts, &block) @conditions = conditions route('HEAD', path, opts, &block) end |
.head(path, opts = {}, &bk) ⇒ Object
1395 |
# File 'lib/sinatra/base.rb', line 1395 def head(path, opts = {}, &bk) route 'HEAD', path, opts, &bk end |
.helpers(*extensions, &block) ⇒ Object
Makes the methods defined in the block and in the Modules given
in extensions available to the handlers and templates
1403 1404 1405 1406 |
# File 'lib/sinatra/base.rb', line 1403 def helpers(*extensions, &block) class_eval(&block) if block_given? include(*extensions) if extensions.any? end |
.inline_templates=(file = nil) ⇒ Object
Load embedded templates from the file; uses the caller's FILE when no file is specified.
1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 |
# File 'lib/sinatra/base.rb', line 1296 def inline_templates=(file = nil) file = (file.nil? || file == true) ? (caller_files.first || File.($0)) : file begin io = ::IO.respond_to?(:binread) ? ::IO.binread(file) : ::IO.read(file) app, data = io.gsub("\r\n", "\n").split(/^__END__$/, 2) rescue Errno::ENOENT app, data = nil end if data if app and app =~ /([^\n]*\n)?#[^\n]*coding: *(\S+)/m encoding = $2 else encoding = settings.default_encoding end lines = app.count("\n") + 1 template = nil force_encoding data, encoding data.each_line do |line| lines += 1 if line =~ /^@@\s*(.*\S)\s*$/ template = force_encoding(String.new, encoding) templates[$1.to_sym] = [template, file, lines] elsif template template << line end end end end |
.layout(name = :layout, &block) ⇒ Object
Define the layout template. The block must return the template source.
1290 1291 1292 |
# File 'lib/sinatra/base.rb', line 1290 def layout(name = :layout, &block) template name, &block end |
.link(path, opts = {}, &bk) ⇒ Object
1398 |
# File 'lib/sinatra/base.rb', line 1398 def link(path, opts = {}, &bk) route 'LINK', path, opts, &bk end |
.middleware ⇒ Object
Middleware used in this class and all superclasses.
1212 1213 1214 1215 1216 1217 1218 |
# File 'lib/sinatra/base.rb', line 1212 def middleware if superclass.respond_to?(:middleware) superclass.middleware + @middleware else @middleware end end |
.mime_type(type, value = nil) ⇒ Object
Lookup or register a mime type in Rack's mime registry.
1328 1329 1330 1331 1332 1333 1334 |
# File 'lib/sinatra/base.rb', line 1328 def mime_type(type, value = nil) return type if type.nil? return type.to_s if type.to_s.include?('/') type = ".#{type}" unless type.to_s[0] == ?. return Rack::Mime.mime_type(type, nil) unless value Rack::Mime::MIME_TYPES[type] = value end |
.mime_types(type) ⇒ Object
provides all mime types matching type, including deprecated types: mime_types :html # => ['text/html'] mime_types :js # => ['application/javascript', 'text/javascript']
1339 1340 1341 1342 |
# File 'lib/sinatra/base.rb', line 1339 def mime_types(type) type = mime_type type type =~ /^application\/(xml|javascript)$/ ? [type, "text/#$1"] : [type] end |
.new(*args, &bk) ⇒ Object
Create a new instance of the class fronted by its middleware pipeline. The object is guaranteed to respond to #call but may not be an instance of the class new was called on.
1486 1487 1488 1489 |
# File 'lib/sinatra/base.rb', line 1486 def new(*args, &bk) instance = new!(*args, &bk) Wrapper.new(build(instance).to_app, instance) end |
.not_found(&block) ⇒ Object
Sugar for error(404) { ... }
1279 1280 1281 |
# File 'lib/sinatra/base.rb', line 1279 def not_found(&block) error(404, &block) end |
.options(path, opts = {}, &bk) ⇒ Object
1396 |
# File 'lib/sinatra/base.rb', line 1396 def (path, opts = {}, &bk) route 'OPTIONS', path, opts, &bk end |
.patch(path, opts = {}, &bk) ⇒ Object
1397 |
# File 'lib/sinatra/base.rb', line 1397 def patch(path, opts = {}, &bk) route 'PATCH', path, opts, &bk end |
.post(path, opts = {}, &bk) ⇒ Object
1393 |
# File 'lib/sinatra/base.rb', line 1393 def post(path, opts = {}, &bk) route 'POST', path, opts, &bk end |
.production? ⇒ Boolean
1420 |
# File 'lib/sinatra/base.rb', line 1420 def production?; environment == :production end |
.prototype ⇒ Object
The prototype instance used to process requests.
1476 1477 1478 |
# File 'lib/sinatra/base.rb', line 1476 def prototype @prototype ||= new end |
.public=(value) ⇒ Object
1369 1370 1371 1372 |
# File 'lib/sinatra/base.rb', line 1369 def public=(value) warn ":public is no longer used to avoid overloading Module#public, use :public_folder or :public_dir instead" set(:public_folder, value) end |
.public_dir ⇒ Object
1378 1379 1380 |
# File 'lib/sinatra/base.rb', line 1378 def public_dir public_folder end |
.public_dir=(value) ⇒ Object
1374 1375 1376 |
# File 'lib/sinatra/base.rb', line 1374 def public_dir=(value) self.public_folder = value end |
.put(path, opts = {}, &bk) ⇒ Object
1392 |
# File 'lib/sinatra/base.rb', line 1392 def put(path, opts = {}, &bk) route 'PUT', path, opts, &bk end |
.quit! ⇒ Object Also known as: stop!
Stop the self-hosted server if running.
1436 1437 1438 1439 1440 1441 1442 1443 |
# File 'lib/sinatra/base.rb', line 1436 def quit! return unless running? # Use Thin's hard #stop! if available, otherwise just #stop. running_server.respond_to?(:stop!) ? running_server.stop! : running_server.stop $stderr.puts "== Sinatra has ended his set (crowd applauds)" unless set :running_server, nil set :handler_name, nil end |
.register(*extensions, &block) ⇒ Object
Register an extension. Alternatively take a block from which an extension will be created and registered on the fly.
1410 1411 1412 1413 1414 1415 1416 1417 |
# File 'lib/sinatra/base.rb', line 1410 def register(*extensions, &block) extensions << Module.new(&block) if block_given? @extensions += extensions extensions.each do |extension| extend extension extension.registered(self) if extension.respond_to?(:registered) end end |
.reset! ⇒ Object
Removes all routes, filters, middleware and extension hooks from the current class (not routes/filters/... defined by its superclass).
1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 |
# File 'lib/sinatra/base.rb', line 1186 def reset! @conditions = [] @routes = {} @filters = {:before => [], :after => []} @errors = {} @middleware = [] @prototype = nil @extensions = [] if superclass.respond_to?(:templates) @templates = Hash.new { |hash, key| superclass.templates[key] } else @templates = {} end end |
.run!(options = {}, &block) ⇒ Object Also known as: start!
Run the Sinatra app as a self-hosted server using Thin, Puma, Mongrel, or WEBrick (in that order). If given a block, will call with the constructed handler once we have taken the stage.
1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 |
# File 'lib/sinatra/base.rb', line 1450 def run!( = {}, &block) return if running? set handler = detect_rack_handler handler_name = handler.name.gsub(/.*::/, '') server_settings = settings.respond_to?(:server_settings) ? settings.server_settings : {} server_settings.merge!(:Port => port, :Host => bind) begin start_server(handler, server_settings, handler_name, &block) rescue Errno::EADDRINUSE $stderr.puts "== Someone is already performing on port #{port}!" raise ensure quit! end end |
.running? ⇒ Boolean
Check whether the self-hosted server is running or not.
1471 1472 1473 |
# File 'lib/sinatra/base.rb', line 1471 def running? running_server? end |
.set(option, value = (not_set = true), ignore_setter = false, &block) ⇒ Object
Sets an option to the given value. If the value is a proc, the proc will be called every time the option is accessed.
1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 |
# File 'lib/sinatra/base.rb', line 1222 def set(option, value = (not_set = true), ignore_setter = false, &block) raise ArgumentError if block and !not_set value, not_set = block, false if block if not_set raise ArgumentError unless option.respond_to?(:each) option.each { |k,v| set(k, v) } return self end if respond_to?("#{option}=") and not ignore_setter return __send__("#{option}=", value) end setter = proc { |val| set option, val, true } getter = proc { value } case value when Proc getter = value when Symbol, Integer, FalseClass, TrueClass, NilClass getter = value.inspect when Hash setter = proc do |val| val = value.merge val if Hash === val set option, val, true end end define_singleton("#{option}=", setter) define_singleton(option, getter) define_singleton("#{option}?", "!!#{option}") unless method_defined? "#{option}?" self end |
.settings ⇒ Object
Access settings defined with Base.set.
934 935 936 |
# File 'lib/sinatra/base.rb', line 934 def self.settings self end |
.template(name, &block) ⇒ Object
Define a named template. The block must return the template source.
1284 1285 1286 1287 |
# File 'lib/sinatra/base.rb', line 1284 def template(name, &block) filename, line = caller_locations.first templates[name] = [block, filename, line.to_i] end |
.test? ⇒ Boolean
1421 |
# File 'lib/sinatra/base.rb', line 1421 def test?; environment == :test end |
.unlink(path, opts = {}, &bk) ⇒ Object
1399 |
# File 'lib/sinatra/base.rb', line 1399 def unlink(path, opts = {}, &bk) route 'UNLINK', path, opts, &bk end |
.use(middleware, *args, &block) ⇒ Object
Use the specified Rack middleware
1430 1431 1432 1433 |
# File 'lib/sinatra/base.rb', line 1430 def use(middleware, *args, &block) @prototype = nil @middleware << [middleware, args, block] end |
Instance Method Details
#call(env) ⇒ Object
Rack call interface.
907 908 909 |
# File 'lib/sinatra/base.rb', line 907 def call(env) dup.call!(env) end |
#call!(env) ⇒ Object
:nodoc:
911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 |
# File 'lib/sinatra/base.rb', line 911 def call!(env) # :nodoc: @env = env @params = IndifferentHash.new @request = Request.new(env) @response = Response.new template_cache.clear if settings.reload_templates @response['Content-Type'] = nil invoke { dispatch! } invoke { error_block!(response.status) } unless @env['sinatra.error'] unless @response['Content-Type'] if Array === body and body[0].respond_to? :content_type content_type body[0].content_type else content_type :html end end @response.finish end |
#forward ⇒ Object
Forward the request to the downstream app -- middleware only.
964 965 966 967 968 969 970 971 |
# File 'lib/sinatra/base.rb', line 964 def forward fail "downstream app not set" unless @app.respond_to? :call status, headers, body = @app.call env @response.status = status @response.body = body @response.headers.merge! headers nil end |
#halt(*response) ⇒ Object
Exit the current block, halts any further processing of the request, and returns the specified response.
951 952 953 954 |
# File 'lib/sinatra/base.rb', line 951 def halt(*response) response = response.first if response.length == 1 throw :halt, response end |
#new! ⇒ Object
Create a new instance without middleware in front of it.
1481 |
# File 'lib/sinatra/base.rb', line 1481 alias new! new |
#options ⇒ Object
943 944 945 946 947 |
# File 'lib/sinatra/base.rb', line 943 def warn "Sinatra::Base#options is deprecated and will be removed, " \ "use #settings instead." settings end |
#pass(&block) ⇒ Object
Pass control to the next matching route. If there are no more matching routes, Sinatra will return a 404 response.
959 960 961 |
# File 'lib/sinatra/base.rb', line 959 def pass(&block) throw :pass, block end |
#settings ⇒ Object
Access settings defined with Base.set.
939 940 941 |
# File 'lib/sinatra/base.rb', line 939 def settings self.class.settings end |